/**
 * This represents a light bulb
 * 
 * @author Kent Archie 
 * @version 1.0
 */
public class Bulb
{
    public final static int TUNGSTEN=0;  // ordinary tungsten type bulb
    public final static int KRYPTON=1; // special krypton bulb
    private final int DEFAULTRATING=6000; // lifetime in minutes
    private int type;  // what kind of bulb is this
    private boolean status;  // is it good (true) or bad (false)
    private int runtime;  // how long has it been running
    private int rating;  // how long is it good for

    /**
     * Constructor for objects of class Bulb
     */
    public Bulb(int ntype)
    {
        type = ntype;
        status = true;
        runtime = 0;
        switch(type) {
            case TUNGSTEN: rating = DEFAULTRATING;
                            break;
            case  KRYPTON: rating = 3000;
                            break;
            default: rating = DEFAULTRATING;
                     break;
        } // esac
    } // Bulb

    /**
     * Constructor for objects of class Bulb
     */
    public Bulb()
    {
        type = TUNGSTEN;
        status = true;
        runtime = 0;
        rating = DEFAULTRATING;
    } // Bulb

    /**
     * Get the bulbs type
     * 
     * @return     the type 
     */
    public int getType()
    {
        return  type;
    } // getType

    /**
     * Get the bulbs status
     * 
     * @return     the status 
     */
    public boolean getStatus()
    {
        return  status;
    } // getStatus

   /**
     * Get the bulb status as a string
     * 
     * @return     the status as a string
     */
    public String statusString()
    {
        return status ? "good" : "bad";
    } // statusString
    
    /** return string form of the Bulb type */
    public String toString()
    {
        switch(type) {
            case TUNGSTEN : return("Tungsten");
            case KRYPTON :  return("Krypton");
            default :       return("iduno");
        } // esac
    } // toString
    
    /** set the status to false to indicate the bulb is burned out */
    private void burnout()
    {
        status = false;
    } // burnout
    
    public boolean checkBulb(int time)
    {
        runtime += time;
        if(runtime > rating) {
            burnout();
            return false;
        }
        else
            return true;
    }  // checkBulb
} // Bulb
